<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:foxml="info:fedora/fedora-system:def/foxml#"
	xmlns:mets="http://www.loc.gov/METS/" xmlns:mods="http://www.loc.gov/mods/v3"
	xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output encoding="UTF-8" method="xml"/>

	<xsl:key name="files" match="mets:mets/mets:fileSec/mets:fileGrp/mets:file" use="@ID"/>

	<xsl:key name="rights" match="mets:mets/mets:amdSec/mets:rightsMD" use="@ID"/>

	<xsl:variable name="with">
		<xsl:text>abcdefghijklmnopqrstuvwyz  </xsl:text>
	</xsl:variable>

	<xsl:variable name="replace">
		<xsl:text>ABCDEFGHIJKLMNOPQRSTUVWYZ,-</xsl:text>
	</xsl:variable>

	<xsl:variable name="baseID">
		<xsl:value-of select="//mets:mets/@OBJID"/>
	</xsl:variable>

	<xsl:variable name="baseWhitmanAddress">
		<xsl:text>http://www.whitmanarchive.org/IOM/</xsl:text>
	</xsl:variable>

	<xsl:variable name="pidFileLoc">
		<xsl:text>file:/c:/whitman/iom/examples/whitman.url.wPIDS.xml</xsl:text>
	</xsl:variable>

	<xsl:variable name="textPID">
		<xsl:for-each select="mets:mets/mets:structMap/mets:div[@TYPE='manuscript' or @TYPE='Printed'  or @TYPE='biography']">
			<xsl:variable name="fileID">
				<xsl:value-of select="mets:fptr/@FILEID"/>
			</xsl:variable>
			<xsl:variable name="getFileName">
				<xsl:call-template name="chop">
					<xsl:with-param name="string">
						<xsl:value-of select="key('files', $fileID)/mets:FLocat/@xlink:href"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>
			<xsl:for-each select="doc($pidFileLoc)//object">
				<xsl:choose>
					<xsl:when test="contains(url,$getFileName)">
						<xsl:value-of select="pid"/>
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>
			</xsl:for-each>
		</xsl:for-each>
	</xsl:variable>

	<xsl:template name="chop">
		<xsl:param name="string"/>
		<xsl:choose>
			<xsl:when test="contains($string,'/')">
				<xsl:variable name="remainingString">
					<xsl:value-of select="substring-after($string,'/')"/>
				</xsl:variable>
				<xsl:call-template name="chop">
					<xsl:with-param name="string">
						<xsl:value-of select="$remainingString"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$string"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template match="/">
		<xsl:apply-templates
			select="mets:mets/mets:structMap//mets:div[@TYPE='page' or @TYPE='manuscript' or @TYPE='Printed' 
			or @TYPE='biography' or @TYPE='figure']"
		/>
	</xsl:template>




	<!-- TEXT TEXT TEXT TEXT TEXT TEXT TEXT TEXT TEXT TEXT -->
	<xsl:template match="mets:div[@TYPE='manuscript' or @TYPE='Printed' 
		or @TYPE='biography']">
		

		<xsl:variable name="fileID">
			<xsl:value-of select="mets:fptr/@FILEID"/>
		</xsl:variable>

		<xsl:variable name="getFileName">
			<xsl:call-template name="chop">
				<xsl:with-param name="string">
					<xsl:value-of select="key('files', $fileID)/mets:FLocat/@xlink:href"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="getPID">
			<xsl:for-each select="doc($pidFileLoc)//object">
				<xsl:choose>
					<xsl:when test="contains(url,$getFileName)">
						
						<xsl:value-of select="pid"/>
						
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>

		<xsl:variable name="WWAPIDurl">
			<xsl:value-of select="$baseWhitmanAddress"/>
			<xsl:for-each select="doc($pidFileLoc)//object">
				<xsl:choose>
					<xsl:when test="contains(url,$getFileName)">
						<xsl:value-of select="url"/>
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>


		<!-- the Foxml file for the TEXT-->
		<xsl:result-document method="xml" indent="yes" href="fedora/{$baseID}.transscript.xml">

			<foxml:digitalObject PID="{$getPID}"
				fedoraxsi:schemaLocation="info:fedora/fedora-system:def/foxml# http://www.fedora.info/definitions/1/0/foxml1-0.xsd"
				xmlns:audit="info:fedora/fedora-system:def/audit#"
				xmlns:fedoraxsi="http://www.w3.org/2001/XMLSchema-instance"
				xmlns:foxml="info:fedora/fedora-system:def/foxml#">
				<foxml:objectProperties>
					<foxml:property NAME="http://www.w3.org/1999/02/22-rdf-syntax-ns#type" VALUE="FedoraObject"/>
					<foxml:property NAME="info:fedora/fedora-system:def/model#state" VALUE="Active"/>
					<foxml:property NAME="info:fedora/fedora-system:def/model#label"
						VALUE="{//mods:name[mods:role/mods:roleTerm='Author']/mods:namePart} : {//mods:titleInfo/mods:title}"/>
					<foxml:property NAME="info:fedora/fedora-system:def/model#contentModel" VALUE="uvaBook"/>
				</foxml:objectProperties>

				<foxml:datastream CONTROL_GROUP="E" ID="DESC" STATE="A" VERSIONABLE="true">
					<!-- Descriptive Metadata -->
					<foxml:datastreamVersion ID="DESC1.0"
						LABEL="Whitman Descriptive Metadata: {$baseWhitmanAddress}/{$baseID}/fedora/{$baseID}.transscript.desc.xml"
						MIMETYPE="text/xml">
						<foxml:contentLocation
							REF="{$baseWhitmanAddress}/{$baseID}/fedora/{$baseID}.transscript.desc.xml" TYPE="URL"/>
					</foxml:datastreamVersion>
				</foxml:datastream>

				<foxml:datastream CONTROL_GROUP="E" ID="POLICY" STATE="A" VERSIONABLE="true">
					<foxml:datastreamVersion ID="POLICY1.0" LABEL="UVA Public Policy: public" MIMETYPE="text/xml">
						<foxml:contentLocation REF="http://text.lib.virginia.edu/policy/permit-to-all.xml" TYPE="URL"
						/>
					</foxml:datastreamVersion>
				</foxml:datastream>

				<foxml:datastream CONTROL_GROUP="X" ID="DC" STATE="A" VERSIONABLE="true">
					<foxml:datastreamVersion ID="DC1.0" LABEL="Fedora Internal OAI Dublin Core Metadata"
						MIMETYPE="text/xml">
						<foxml:xmlContent>
							<oai_dc:dc xmlns="http://www.fedora.info/definitions/"
								xmlns:dc="http://purl.org/dc/elements/1.1/"
								xmlns:oai_dc="http://www.openarchives.org/OAI/2.0/oai_dc/"
								xmlns:xlink="http://www.w3.org/TR/xlink"
								xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
								<dc:creator>
									<xsl:value-of select="//mods:name[mods:role/mods:roleTerm='Author']/mods:namePart"/>
								</dc:creator>
								<dc:title>
									<xsl:value-of select="//mods:titleInfo/mods:title"/>
								</dc:title>
								<dc:identifier>
									<xsl:value-of select="$getPID"/>
								</dc:identifier>
							</oai_dc:dc>
						</foxml:xmlContent>
					</foxml:datastreamVersion>
				</foxml:datastream>
				<!-- Administrative Metadata -->
				<foxml:datastream CONTROL_GROUP="E" ID="ADMIN" STATE="A" VERSIONABLE="true">
					<foxml:datastreamVersion ID="ADMIN1.0"
						LABEL="Whitman Administrative Metadata: {$baseWhitmanAddress}/{$baseID}/fedora/{$baseID}.transscript.admin.xml"
						MIMETYPE="text/xml">
						<foxml:contentLocation
							REF="{$baseWhitmanAddress}/{$baseID}/fedora/{$baseID}.transscript.admin.xml" TYPE="URL"/>
					</foxml:datastreamVersion>
				</foxml:datastream>

				<!-- This is the tei xml datastream!! -->
				<foxml:datastream CONTROL_GROUP="E" ID="TEI" STATE="A" VERSIONABLE="true">
					<foxml:datastreamVersion ID="TEI1.0" MIMETYPE="text/xml">
						<xsl:attribute name="LABEL">
							<xsl:text>WWA </xsl:text>
							<xsl:value-of select="//mets:mets/@TYPE"/>
							<xsl:text> : </xsl:text>
							<xsl:value-of select="$WWAPIDurl"/>
						</xsl:attribute>
						<foxml:contentLocation REF="{$WWAPIDurl}" TYPE="URL"/>
					</foxml:datastreamVersion>
				</foxml:datastream>

				<foxml:disseminator BDEF_CONTRACT_PID="uva-lib-bdef:103" ID="DISS3" STATE="A" VERSIONABLE="true">
					<foxml:disseminatorVersion BMECH_SERVICE_PID="uva-lib-bmech:112" ID="DISS3.0"
						LABEL="uvaGenText Service Binding.">
						<foxml:serviceInputMap>
							<foxml:datastreamBinding DATASTREAM_ID="TEI" KEY="teiSource"
								LABEL="Binding to TEI source file." ORDER="0"/>
						</foxml:serviceInputMap>
					</foxml:disseminatorVersion>
				</foxml:disseminator>

				<foxml:disseminator BDEF_CONTRACT_PID="uva-lib-bdef:100" ID="DISS1" STATE="A" VERSIONABLE="true">
					<foxml:disseminatorVersion BMECH_SERVICE_PID="uva-lib-bmech:103" ID="DISS1.0"
						LABEL="uvaDefault Service Binding.">
						<foxml:serviceInputMap>
							<foxml:datastreamBinding DATASTREAM_ID="TEI" KEY="teiSource"
								LABEL="Binding to TEI source file" ORDER="0"/>
							<foxml:datastreamBinding DATASTREAM_ID="DESC" KEY="descMeta"
								LABEL="Binding to WWA Descriptive Metadata" ORDER="0"/>
							<foxml:datastreamBinding DATASTREAM_ID="DC" KEY="NULLBIND"
								LABEL="Binding to Dublin Core Metadata" ORDER="0"/>
						</foxml:serviceInputMap>
					</foxml:disseminatorVersion>
				</foxml:disseminator>

				<foxml:disseminator BDEF_CONTRACT_PID="uva-lib-bdef:108" ID="DISS6" STATE="A" VERSIONABLE="true">
					<foxml:disseminatorVersion BMECH_SERVICE_PID="uva-lib-bmech:118" ID="DISS6.0"
						LABEL="uvaRelation Service Binding.">
						<foxml:serviceInputMap>
							<foxml:datastreamBinding DATASTREAM_ID="TEI" KEY="teiSource"
								LABEL="Binding to TEI source file" ORDER="0"/>
						</foxml:serviceInputMap>
					</foxml:disseminatorVersion>
				</foxml:disseminator>

				<foxml:disseminator BDEF_CONTRACT_PID="uva-lib-bdef:105" ID="DISS4" STATE="A" VERSIONABLE="true">
					<foxml:disseminatorVersion BMECH_SERVICE_PID="uva-lib-bmech:114" ID="DISS4.0"
						LABEL="uvaPageBook Service Binding.">
						<foxml:serviceInputMap>
							<foxml:datastreamBinding DATASTREAM_ID="TEI" KEY="teiSource"
								LABEL="Binding to TEI source file." ORDER="0"/>
						</foxml:serviceInputMap>
					</foxml:disseminatorVersion>
				</foxml:disseminator>
				<foxml:disseminator BDEF_CONTRACT_PID="uva-lib-bdef:109" ID="DISS5" STATE="A" VERSIONABLE="true">
					<foxml:disseminatorVersion BMECH_SERVICE_PID="uva-lib-bmech:124" ID="DISS5.0"
						LABEL="uvaOKI Service Binding.">
						<foxml:serviceInputMap>
							<foxml:datastreamBinding DATASTREAM_ID="DC" KEY="NULLBIND"
								LABEL="Binding to Dublin Core Metadata" ORDER="0"/>
						</foxml:serviceInputMap>
					</foxml:disseminatorVersion>
				</foxml:disseminator>
				<foxml:disseminator BDEF_CONTRACT_PID="uva-lib-bdef:101" ID="DISS2" STATE="A" VERSIONABLE="true">
					<foxml:disseminatorVersion BMECH_SERVICE_PID="uva-lib-bmech:108" ID="DISS2.0"
						LABEL="uvaMeta Service Binding.">
						<foxml:serviceInputMap>
							<foxml:datastreamBinding DATASTREAM_ID="DC" KEY="dc" LABEL="Binding to Dublin Core Metadata"
								ORDER="0"/>
							<foxml:datastreamBinding DATASTREAM_ID="DESC" KEY="descMeta"
								LABEL="Binding to WWA Descriptive Metadata" ORDER="0"/>
							<foxml:datastreamBinding DATASTREAM_ID="ADMIN" KEY="adminMeta"
								LABEL="Binding to WWA Administrative Metadata" ORDER="0"/>
						</foxml:serviceInputMap>
					</foxml:disseminatorVersion>
				</foxml:disseminator>
			</foxml:digitalObject>
		</xsl:result-document>

		<!-- descriptive metadata 
		Issues: the Fedora desc data appears to be primarily about the 
		original, but it is mixed: <surrogate> is used for the digital. METS 
		supplies inline only the digital desc. The remainder is in EAD instance for manuscript. -->

		<xsl:result-document method="xml" indent="yes" exclude-result-prefixes="#all"
			doctype-system="http://text.lib.virginia.edu/dtd/descmeta/descmeta.dtd"
			href="fedora/{$baseID}.transcript.desc.xml">
			<descmeta>
				<pid>
					<xsl:for-each select="doc($pidFileLoc)//object">
						<xsl:choose>
							<xsl:when test="contains(url,$getFileName)">
								<xsl:value-of select="desc/pid"/>
							</xsl:when>
							<xsl:otherwise/>
						</xsl:choose>
					</xsl:for-each>
				</pid>
				<mediatype type="text">
					<form scheme="WWA">
						<xsl:value-of select="//mets:mets/@TYPE"/>
					</form>
				</mediatype>
				<presentation>
					<displayAgent>
						<xsl:value-of select="//mods:name[mods:role/mods:roleTerm='Author']/mods:namePart"/>
					</displayAgent>
					<sortAgent>
						<xsl:value-of
							select="translate(//mods:name[mods:role/mods:roleTerm='Author']/mods:namePart,$replace,$with)"
						/>
					</sortAgent>
					<displayTitle>
						<xsl:value-of select="//mods:titleInfo/mods:title"/>
					</displayTitle>
					<sortTitle>
						<xsl:value-of select="translate(//mods:mods/mods:titleInfo/mods:title,$replace,$with)"/>
					</sortTitle>
				</presentation>
				<agent type="creator" form="persname" role="author">
					<name>
						<xsl:value-of select="//mods:name[mods:role/mods:roleTerm='Author']/mods:namePart"/>
					</name>
				</agent>
				<title type="main">
					<xsl:value-of select="//mods:titleInfo/mods:title"/>
				</title>
				<xsl:if test="//mods:classification[@authority='lcc']">
					<identifier type="Library of Congress Classification">
						<xsl:value-of select="//mods:classification[@authority='lcc']"/>
					</identifier>
				</xsl:if>
				<xsl:if test="//mods:languageTerm[@authority='iso639-2b']">
					<language>
						<authority scheme="http://www.loca.gov/standards/iso639-2/">ISO 639-2</authority>
						<xsl:value-of select="//mods:languageTerm[@authority='iso639-2b']"/>
					</language>
				</xsl:if>
				<physdesc type="extent">[Unavailable: in EAD record that is not given]</physdesc>
				<surrogate>
					<mediatype type="text"/>
					<mimetype>text/xml</mimetype>
					<title type="main">
						<xsl:value-of select="//mods:titleInfo/mods:title"/>
					</title>
					<place>
						<geogname>Lincoln, Nebraska</geogname>
					</place>
					<agent type="provider" form="corpname" role="publisher">
						<name>The Center for Digital Research in the Humanities </name>
					</agent>
					<agent type="provider" form="corpname" role="publisher">
						<name>Walt Whitman Archive</name>
					</agent>
					<time type="creation">
						<date>
							<xsl:value-of select="//mods:dateIssued"/>
						</date>
					</time>
					<rights type="copyright">
						<xsl:text>Copyright &#169; </xsl:text>
						<xsl:value-of select="//mods:dateIssued"/>
						<xsl:text> </xsl:text>
						<xsl:for-each select="key('files', $fileID)">
							<xsl:variable name="rightsID">
								<xsl:value-of select="normalize-space(substring-before(@ADMID,' '))"/>
							</xsl:variable>
							<xsl:value-of select="normalize-space(key('rights',$rightsID))"/>
						</xsl:for-each>
					</rights>
					<rights type="access">Publicly accessible</rights>
				</surrogate>

			</descmeta>

		</xsl:result-document>

		<!-- Administrative Metadata for the TEXT -->
		<xsl:result-document method="xml" indent="yes" exclude-result-prefixes="#all"
			doctype-system="http://text.lib.virginia.edu/dtd/admin/adminmeta.dtd"
			href="fedora/{$baseID}.transcript.admin.xml">
			<adminmeta>
				<pid>
					<xsl:for-each select="doc($pidFileLoc)//object">
						<xsl:choose>
							<xsl:when test="contains(url,$getFileName)">
								<xsl:value-of select="admin/pid"/>
							</xsl:when>
							<xsl:otherwise/>
						</xsl:choose>
					</xsl:for-each>
				</pid>
				<adminrights>
					<policy>
						<access>public</access>
					</policy>
				</adminrights>
				<technical>
					<text>
						<character encoding="UTF-8"/>
						<mimetype>text/xml</mimetype>
						<markup>
							<encoding label="xml" version="1.0"/>
							<base label="TEI.2" type="DTD" version="P4"
								href="http://www.tei-c.org/Guidelines/P4/p4dtd.xml">
								<localmodification label="TEI.extensions.dtd"
									href="{$baseWhitmanAddress}/shared/whitman/whitman.ext.dtd"/>
								<localmodification label="TEI.extensions.ent"
									href="{$baseWhitmanAddress}/shared/whitman/whitman.ext.ent"/>
							</base>
						</markup>
					</text>
				</technical>
			</adminmeta>
		</xsl:result-document>
	</xsl:template>



	<!-- IMAGE IMAGE IMAGE IMAGE IMAGE IMAGE IMAGE -->
	<xsl:template match="mets:div[@TYPE='page'  or @TYPE='figure']">

		<xsl:variable name="fileID">
			<xsl:value-of select="mets:fptr/@FILEID"/>
		</xsl:variable>

		<xsl:variable name="position">
			<xsl:number format="001"/>
		</xsl:variable>

		<xsl:variable name="getFileName">
			<xsl:call-template name="chop">
				<xsl:with-param name="string">
					<xsl:value-of select="key('files', $fileID)/mets:FLocat/@xlink:href"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="getPID">
			<xsl:for-each select="doc($pidFileLoc)//object">
				<xsl:choose>
					<xsl:when test="contains(url,$getFileName)">
						<xsl:value-of select="pid"/>
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>

		<xsl:variable name="WWAPIDurl">
			<xsl:value-of select="$baseWhitmanAddress"/>
			<xsl:for-each select="doc($pidFileLoc)//object">
				<xsl:choose>
					<xsl:when test="contains(url,$getFileName)">
						<xsl:value-of select="url"/>
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>
		<!-- Writes the FOXML file for each image -->
		<xsl:result-document method="xml" indent="yes" href="fedora/{$baseID}.Img{$position}.xml">
			<foxml:digitalObject PID="{$getPID}"
				fedoraxsi:schemaLocation="info:fedora/fedora-system:def/foxml# http://www.fedora.info/definitions/1/0/foxml1-0.xsd"
				xmlns:audit="info:fedora/fedora-system:def/audit#"
				xmlns:fedoraxsi="http://www.w3.org/2001/XMLSchema-instance"
				xmlns:foxml="info:fedora/fedora-system:def/foxml#">
				<foxml:objectProperties>
					<foxml:property NAME="http://www.w3.org/1999/02/22-rdf-syntax-ns#type" VALUE="FedoraObject"/>
					<foxml:property NAME="info:fedora/fedora-system:def/model#state" VALUE="Active"/>
					<foxml:property NAME="info:fedora/fedora-system:def/model#label">
						<xsl:attribute name="VALUE">
							<xsl:value-of select="//mods:name[mods:role/mods:roleTerm='Author']/mods:namePart"/>
							<xsl:text> : </xsl:text>
							<xsl:value-of select="//mods:titleInfo/mods:title"/>
							<xsl:text> : </xsl:text>
							<xsl:value-of select="@LABEL"/>
						</xsl:attribute>
					</foxml:property>
					<foxml:property NAME="info:fedora/fedora-system:def/model#contentModel" VALUE="uvaLowRes"/>
				</foxml:objectProperties>
				<foxml:datastream CONTROL_GROUP="E" ID="DESC" STATE="A" VERSIONABLE="true">

					<!-- Descriptive Metadata datastream -->
					<foxml:datastreamVersion ID="DESC1.0"
						LABEL="Whitman Descriptive Metadata: {$baseWhitmanAddress}/{$baseID}/fedora/{$baseID}.Img{$position}.desc.xml"
						MIMETYPE="text/xml">
						<foxml:contentLocation
							REF="{$baseWhitmanAddress}/{$baseID}/fedora/{$baseID}.Img{$position}.desc.xml" TYPE="URL"/>
					</foxml:datastreamVersion>

				</foxml:datastream>

				<!-- Screen sized image datastream -->
				<foxml:datastream CONTROL_GROUP="E" ID="SCREEN" STATE="A" VERSIONABLE="true">
					<foxml:datastreamVersion ID="SCREEN1.0" MIMETYPE="image/jpeg">
						<xsl:attribute name="LABEL">
							<xsl:text>Screen sized image: </xsl:text>
							<xsl:value-of select="$WWAPIDurl"/>
						</xsl:attribute>
						<foxml:contentLocation REF="{$WWAPIDurl}" TYPE="URL"/>
					</foxml:datastreamVersion>
				</foxml:datastream>

				<!-- Thumbnail image datastream. -->
				<foxml:datastream CONTROL_GROUP="E" ID="PREVIEW" STATE="A" VERSIONABLE="true">
					<foxml:datastreamVersion ID="PREVIEW1.0"
						MIMETYPE="image/jpeg">
						<xsl:attribute name="LABEL">
							<xsl:text>Thumbnail sized image:  </xsl:text>
							<xsl:value-of select="substring-before($WWAPIDurl, '.jpg')"/>
							<xsl:text>.pre.jpg</xsl:text>
						</xsl:attribute>		
						<xsl:text>&#x0A;</xsl:text>
						<xsl:comment>Need to generate thumbnail images.</xsl:comment>
						<xsl:text>&#x0A;</xsl:text>	
						<foxml:contentLocation REF="{substring-before($WWAPIDurl, '.jpg')}.pre.jpg" TYPE="URL"/>
					</foxml:datastreamVersion>
				</foxml:datastream>
				<foxml:datastream CONTROL_GROUP="E" ID="POLICY" STATE="A" VERSIONABLE="true">
					<foxml:datastreamVersion ID="POLICY1.0" LABEL="Publicly Accessible" MIMETYPE="text/xml">
						<foxml:contentLocation REF="http://text.lib.virginia.edu/policy/permit-to-all.xml" TYPE="URL"
						/>
					</foxml:datastreamVersion>
				</foxml:datastream>
				
				<!-- Dublin core datastream -->
				<foxml:datastream CONTROL_GROUP="X" ID="DC" STATE="A" VERSIONABLE="true">
					<foxml:datastreamVersion ID="DC1.0" LABEL="Fedora Internal OAI Dublin Core Metadata"
						MIMETYPE="text/xml">
						<foxml:xmlContent>
							<oai_dc:dc xmlns="http://www.fedora.info/definitions/"
								xmlns:dc="http://purl.org/dc/elements/1.1/"
								xmlns:oai_dc="http://www.openarchives.org/OAI/2.0/oai_dc/"
								xmlns:xlink="http://www.w3.org/TR/xlink"
								xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
								<dc:creator>
									<xsl:value-of select="//mods:name[mods:role/mods:roleTerm='Author']/mods:namePart"/>
								</dc:creator>
								<dc:title>
									<xsl:value-of select="//mods:titleInfo/mods:title"/>
									<xsl:text> </xsl:text>
									<xsl:value-of select="@LABEL"/>
								</dc:title>
								<dc:identifier>
									<xsl:value-of select="$getPID"/>
								</dc:identifier>
							</oai_dc:dc>
						</foxml:xmlContent>
					</foxml:datastreamVersion>
				</foxml:datastream>

				<!-- Administrative Metadata datastream -->
				<foxml:datastream CONTROL_GROUP="E" ID="ADMIN" STATE="A" VERSIONABLE="true">
					<xsl:text>&#x0A;</xsl:text>
					<xsl:comment> need to clarify. What does this look like? Can I generate it from the METS? </xsl:comment>
					<xsl:text>&#x0A;</xsl:text>
					<foxml:datastreamVersion ID="ADMIN1.0"
						LABEL="WWA Administrative Metadata: {$baseWhitmanAddress}/{$baseID}/fedora/{$baseID}.Img{$position}.admin.xml"  
						MIMETYPE="text/xml">
						<foxml:contentLocation
							REF="{$baseWhitmanAddress}/{$baseID}/fedora/{$baseID}.Img{$position}.admin.xml"
							TYPE="URL"/>
					</foxml:datastreamVersion>
				</foxml:datastream>

				<foxml:disseminator BDEF_CONTRACT_PID="uva-lib-bdef:102" ID="DISS3" STATE="A" VERSIONABLE="true">
					<foxml:disseminatorVersion BMECH_SERVICE_PID="uva-lib-bmech:111" ID="DISS3.0"
						LABEL="uvaLowRes Service Binding">
						<foxml:serviceInputMap>
							<foxml:datastreamBinding DATASTREAM_ID="SCREEN" KEY="screenImage"
								LABEL="Binding to screen sized image" ORDER="0"/>
							<foxml:datastreamBinding DATASTREAM_ID="PREVIEW" KEY="previewImage"
								LABEL="Binding to thumbnail" ORDER="0"/>
							<foxml:datastreamBinding DATASTREAM_ID="SCREEN" KEY="screenImage"
								LABEL="Binding to max image size" ORDER="0"/>
						</foxml:serviceInputMap>
					</foxml:disseminatorVersion>
				</foxml:disseminator>
				<foxml:disseminator BDEF_CONTRACT_PID="uva-lib-bdef:100" ID="DISS1" STATE="A" VERSIONABLE="true">
					<foxml:disseminatorVersion BMECH_SERVICE_PID="uva-lib-bmech:102" ID="DISS1.0"
						LABEL="uvaDefault Service Binding">
						<foxml:serviceInputMap>
							<foxml:datastreamBinding DATASTREAM_ID="PREVIEW" KEY="previewImage"
								LABEL="Binding to thumbnail" ORDER="0"/>
							<foxml:datastreamBinding DATASTREAM_ID="DESC" KEY="descMeta"
								LABEL="Binding to Uva Descriptive metadata" ORDER="0"/>
							<foxml:datastreamBinding DATASTREAM_ID="SCREEN" KEY="screenImage"
								LABEL="Binding to screen sized image" ORDER="0"/>
							<foxml:datastreamBinding DATASTREAM_ID="SCREEN" KEY="screenImage"
								LABEL="Binding to screen sized image" ORDER="0"/>
							<foxml:datastreamBinding DATASTREAM_ID="DC" KEY="NULLBIND"
								LABEL="Binding to Dublin Core Metadata" ORDER="0"/>
						</foxml:serviceInputMap>
					</foxml:disseminatorVersion>
				</foxml:disseminator>
				<foxml:disseminator BDEF_CONTRACT_PID="uva-lib-bdef:109" ID="DISS4" STATE="A" VERSIONABLE="true">
					<foxml:disseminatorVersion BMECH_SERVICE_PID="uva-lib-bmech:128" ID="DISS4.0"
						LABEL="uvaOKI Service Binding">
						<foxml:serviceInputMap>
							<foxml:datastreamBinding DATASTREAM_ID="DC" KEY="NULLBIND"
								LABEL="Binding to Dublin Core Metadata" ORDER="0"/>
						</foxml:serviceInputMap>
					</foxml:disseminatorVersion>
				</foxml:disseminator>
				<foxml:disseminator BDEF_CONTRACT_PID="uva-lib-bdef:110" ID="DISS5" STATE="A" VERSIONABLE="true">
					<foxml:disseminatorVersion BMECH_SERVICE_PID="uva-lib-bmech:121" ID="DISS5.0"
						LABEL="uvaImageDownload Service Binding">
						<foxml:serviceInputMap>
							<foxml:datastreamBinding DATASTREAM_ID="SCREEN" KEY="imageSource"
								LABEL="Binding to Screen sized image." ORDER="0"/>
						</foxml:serviceInputMap>
					</foxml:disseminatorVersion>
				</foxml:disseminator>
				<foxml:disseminator BDEF_CONTRACT_PID="uva-lib-bdef:101" ID="DISS2" STATE="A" VERSIONABLE="true">
					<foxml:disseminatorVersion BMECH_SERVICE_PID="uva-lib-bmech:108" ID="DISS2.0"
						LABEL="uvaMeta Service Binding">
						<foxml:serviceInputMap>
							<foxml:datastreamBinding DATASTREAM_ID="DC" KEY="dc" LABEL="Binding to Dublin Core Metadata"
								ORDER="0"/>
							<foxml:datastreamBinding DATASTREAM_ID="ADMIN" KEY="adminMeta"
								LABEL="Binding to Uva Administrative metadata" ORDER="0"/>
							<foxml:datastreamBinding DATASTREAM_ID="DESC" KEY="descMeta"
								LABEL="Binding to Uva Descriptive metadata" ORDER="0"/>
						</foxml:serviceInputMap>
					</foxml:disseminatorVersion>
				</foxml:disseminator>
			</foxml:digitalObject>

		</xsl:result-document>

		<!-- IMAGE DESC METADATA -->

		<xsl:result-document method="xml" indent="yes" exclude-result-prefixes="#all"
			doctype-system="http://text.lib.virginia.edu/dtd/descmeta/descmeta.dtd"
			href="fedora/{$baseID}.Img{$position}.desc.xml">
			<descmeta>
				<pid>
					<xsl:for-each select="doc($pidFileLoc)//object">
						<xsl:choose>
							<xsl:when test="contains(url,$getFileName)">
								<xsl:value-of select="desc/pid"/>
							</xsl:when>
							<xsl:otherwise/>
						</xsl:choose>
					</xsl:for-each>
				</pid>
				<mediatype type="image"/>
				<identifier type="parent">
					<xsl:value-of select="$textPID"/>
				</identifier>
				<rights type="copyright">
					<xsl:text>Copyright &#169; </xsl:text>
					<xsl:value-of select="//mods:dateIssued"/>
					<xsl:text> </xsl:text>
					<xsl:for-each select="key('files', $fileID)">

						<xsl:variable name="rightsID">
							<xsl:choose>
								<!-- Needs to be more precise. How does one distinguish between the roles of multiple IDREFS. Name? -->
								<xsl:when test="parent::mets:fileGrp[@ADMID]">
									<xsl:value-of select="normalize-space(parent::mets:fileGrp/@ADMID)"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="normalize-space(substring-before(@ADMID,' '))"/>
								</xsl:otherwise>
							</xsl:choose>

						</xsl:variable>
						<xsl:value-of select="normalize-space(key('rights',$rightsID))"/>
					</xsl:for-each>
				</rights>
				<rights type="access">Publicly accessible</rights>
				<title>
					<xsl:value-of select="//mods:titleInfo/mods:title"/>
					<xsl:text> </xsl:text>
					<xsl:value-of select="@LABEL"/>
				</title>
			</descmeta>

		</xsl:result-document>
		<!-- IMAGE ADMIN METADATA -->

		<xsl:result-document method="xml" indent="yes" exclude-result-prefixes="#all"
			doctype-system="http://text.lib.virginia.edu/dtd/admin/adminmeta.dtd"
			href="fedora/{$baseID}.Img{$position}.admin.xml">
			<adminmeta>
				<pid>
					<xsl:for-each select="doc($pidFileLoc)//object">
						<xsl:choose>
							<xsl:when test="contains(url,$getFileName)">
								<xsl:value-of select="admin/pid"/>
							</xsl:when>
							<xsl:otherwise/>
						</xsl:choose>
					</xsl:for-each>
				</pid>
				<identifier type="WWA FILE ID">
					<xsl:value-of select="$getFileName"/>
				</identifier>
				<adminrights>
					<policy>
						<access>public</access>
					</policy>
				</adminrights>
				<technical>
					<image>
						<filesize type="kilobytes">
							<xsl:value-of select="round(//mets:file[@ID=$fileID]/@SIZE div 1000)"/>
						</filesize>
						<format>
							<mimetype>
								<xsl:value-of select="//mets:file[@ID=$fileID]/@MIMETYPE"/>
							</mimetype>
							<compression>Not specified</compression>
							<colorspace>Not specified</colorspace>
						</format>
						<spatialmetrics>
							<imagewidth type="pixels">Not specified</imagewidth>
							<imagelength type="pixels">Not specified</imagelength>
							<sourceX>Not specified</sourceX>
							<sourceY>Not specified</sourceY>
						</spatialmetrics>
					</image>
				</technical>
			</adminmeta>
		</xsl:result-document>
	</xsl:template>

</xsl:stylesheet>
